---
title: "BMP180"
linkTitle: "BMP180"
weight: 4
description: >
  Bosch Digital Temperature / Pressure Sensor
---

## Registers

### Register to write commands
Register stores what the measurement type should be

### Pressure calibration AC1
For calibration

### Pressure calibration AC2
For calibration

### Pressure calibration VB1
For calibration

### Pressure calibration VB2
For calibration

### Register that stores measurement results
Register stores most recent measurement result

### Temperature calibration 3
For calibration

### Temperature calibration 4
For calibration

### Temperature calibration 5
For calibration

### Temperature calibration 6
For calibration

### Temperature calibration MC
For calibration

### Temperature calibration MD
For calibration

## License
Licensed under [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html#licenseText).

_BMP180 version 0.1.0_

_Based on Cyanobyte spec version 0.1.0_

_Generated from Cyanobyte Codegen version 0.1.0_